@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "1.0.0"
 __keywords__ = ["aria2 rpc client"]
 
 
@@ -10,6 +10,6 @@ if not __version__.endswith(".0"):
     os._exit(1)
 
 
-from .core import *
+from .core import aria2_rpc_api, system_rpc_api
 # from .utils import *
 
